@@ -9,12 +9,12 @@ use IO::File 1.03 ();
 our @todelete;
 END { unlink @todelete; }
 
-sub write_header($$) {
-	my($basename, $outdir) = @_;
+sub write_header($$$) {
+	my($basename, $outdir, $prefix) = @_;
 	require Devel::CallChecker;
 	no strict "refs";
 	my $content = &{"Devel::CallChecker::${basename}_h"}();
-	my $h_file = File::Spec->catfile($outdir, "${basename}.h");
+	my $h_file = File::Spec->catfile($outdir, "${prefix}_${basename}.h");
 	push @todelete, $h_file;
 	my $fh = IO::File->new($h_file, "w") or die $!;
 	$fh->printflush($content) or die $!;
